@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
 class APIError(Exception):
-    """Base class for exceptions raised by plone.restapi.
-    """
+    """Base class for exceptions raised by plone.restapi."""
 
 
 class DeserializationError(Exception):
-    """An error happened during deserialization of content.
-    """
+    """An error happened during deserialization of content."""
 
     def __init__(self, msg):
         self.msg = msg
@@ -16,5 +14,4 @@ class DeserializationError(Exception):
 
 
 class QueryParsingError(Exception):
-    """An error happened while parsing a search query.
-    """
+    """An error happened while parsing a search query."""
