@@ -2,7 +2,8 @@
 
 from AccessControl import getSecurityManager
 from Products.CMFCore.permissions import ModifyPortalContent
-
+from plone.app.contenttypes.interfaces import ILink
+from plone.app.contenttypes.utils import replace_link_variables_by_paths
 from plone.app.textfield.interfaces import IRichText
 from plone.dexterity.interfaces import IDexterityContent
 from plone.namedfile.interfaces import INamedFileField
@@ -12,12 +13,14 @@ from plone.restapi.imaging import get_scales
 from plone.restapi.interfaces import IFieldSerializer
 from plone.restapi.interfaces import IPrimaryFieldTarget
 from plone.restapi.serializer.converters import json_compatible
+from zope.component import getMultiAdapter
 from zope.component import adapter
 from zope.interface import implementer
 from zope.interface import Interface
 from zope.schema.interfaces import IChoice
 from zope.schema.interfaces import ICollection
 from zope.schema.interfaces import IField
+from zope.schema.interfaces import ITextLine
 from zope.schema.interfaces import IVocabularyTokenized
 
 import logging
@@ -79,7 +82,7 @@ class CollectionFieldSerializer(DefaultFieldSerializer):
                     term = value_type.vocabulary.getTerm(v)
                     values.append({u"token": term.token, u"title": term.title})
                 except LookupError:
-                    log.warn("Term lookup error: %r" % v)
+                    log.warning("Term lookup error: %r" % v)
             value = values
         return json_compatible(value)
 
@@ -132,6 +135,22 @@ class RichttextFieldSerializer(DefaultFieldSerializer):
         return json_compatible(value, self.context)
 
 
+@adapter(ITextLine, ILink, Interface)
+class TextLineFieldSerializer(DefaultFieldSerializer):
+    def __call__(self):
+        if self.field.getName() != "remoteUrl":
+            return super(TextLineFieldSerializer, self).__call__()
+        value = self.get_value()
+        path = replace_link_variables_by_paths(context=self.context, url=value)
+        portal = getMultiAdapter(
+            (self.context, self.context.REQUEST), name="plone_portal_state"
+        ).portal()
+        ref_obj = portal.restrictedTraverse(path, None)
+        if ref_obj:
+            value = ref_obj.absolute_url()
+        return json_compatible(value)
+
+
 @adapter(IField, IDexterityContent, Interface)
 @implementer(IPrimaryFieldTarget)
 class DefaultPrimaryFieldTarget(object):
