@@ -20,9 +20,9 @@ logger = logging.getLogger("Plone")
 
 class Addons(object):
     """Performs install/upgrade/uninstall functions on an addon.
-       Pulled, mostly intact, from Plone 5.1's products control panel.
-       If we reach the point when plone.restapi isn't supporting releases
-       prior to 5.1, we might be able to remove this as duplicate code.
+    Pulled, mostly intact, from Plone 5.1's products control panel.
+    If we reach the point when plone.restapi isn't supporting releases
+    prior to 5.1, we might be able to remove this as duplicate code.
     """
 
     def __init__(self, context, request):
@@ -68,7 +68,13 @@ class Addons(object):
             prof
             for prof in profiles
             if prof["type"] == EXTENSION
-            and (prof["product"] in (product_id, "Products.{0}".format(product_id),))
+            and (
+                prof["product"]
+                in (
+                    product_id,
+                    "Products.{0}".format(product_id),
+                )
+            )
         ]
         return profiles
 
