@@ -6,17 +6,18 @@ from plone import api
 from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
 from plone.app.i18n.locales.interfaces import IContentLanguages
 from plone.app.i18n.locales.interfaces import IMetadataLanguages
+from plone.app.iterate.testing import PLONEAPPITERATEDEX_FIXTURE
 from plone.app.testing import applyProfile
 from plone.app.testing import FunctionalTesting
 from plone.app.testing import IntegrationTesting
 from plone.app.testing import login
-from plone.app.testing import PLONE_FIXTURE
 from plone.app.testing import PloneSandboxLayer
 from plone.app.testing import quickInstallProduct
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
 from plone.app.testing import TEST_USER_ID
+from plone.i18n.interfaces import ILanguageSchema
 from plone.registry.interfaces import IRegistry
 from plone.restapi.tests.dxtypes import INDEXES as DX_TYPES_INDEXES
 from plone.restapi.tests.helpers import add_catalog_indexes
@@ -50,26 +51,6 @@ try:
 except pkg_resources.DistributionNotFound:
     PAM_INSTALLED = False
 
-try:
-    from Products.CMFPlone.factory import _IMREALLYPLONE5  # noqa
-except ImportError:
-    PLONE_5 = False  # pragma: no cover
-else:
-    PLONE_5 = True  # pragma: no cover
-
-try:
-    pkg_resources.get_distribution("Products.Archetypes")
-except pkg_resources.DistributionNotFound:
-    HAS_AT = False
-else:
-    HAS_AT = True
-
-try:
-    pkg_resources.get_distribution("plone.dexterity")
-except pkg_resources.DistributionNotFound:
-    HAS_DX = False
-else:
-    HAS_DX = True
 
 ENABLED_LANGUAGES = ["de", "en", "es", "fr"]
 
@@ -98,20 +79,9 @@ def enable_request_language_negotiation(portal):
     This is so we can use the Accept-Language header to request translated
     pieces of content in different languages.
     """
-    if PLONE_5:
-        try:
-            # Plone 5.2+
-            from plone.i18n.interfaces import ILanguageSchema
-        except ImportError:  # pragma: no cover
-            # Plone 5.0/5.1
-            from Products.CMFPlone.interfaces import ILanguageSchema
-
-        registry = getUtility(IRegistry)
-        settings = registry.forInterface(ILanguageSchema, prefix="plone")
-        settings.use_request_negotiation = True
-    else:
-        lang_tool = getToolByName(portal, "portal_languages")
-        lang_tool.use_request_negotiation = True
+    registry = getUtility(IRegistry)
+    settings = registry.forInterface(ILanguageSchema, prefix="plone")
+    settings.use_request_negotiation = True
 
 
 class DateTimeFixture(Layer):
@@ -200,6 +170,21 @@ PLONE_RESTAPI_DX_FUNCTIONAL_TESTING = FunctionalTesting(
 )
 
 
+class PloneRestApiTestWorkflowsLayer(PloneSandboxLayer):
+
+    defaultBases = (PLONE_RESTAPI_DX_FIXTURE,)
+
+    def setUpPloneSite(self, portal):
+        applyProfile(portal, "plone.restapi:testing-workflows")
+
+
+PLONE_RESTAPI_WORKFLOWS_FIXTURE = PloneRestApiTestWorkflowsLayer()
+PLONE_RESTAPI_WORKFLOWS_INTEGRATION_TESTING = IntegrationTesting(
+    bases=(PLONE_RESTAPI_WORKFLOWS_FIXTURE,),
+    name="PloneRestApiTestWorkflowsLayer:Integration",
+)
+
+
 class PloneRestApiDXPAMLayer(PloneSandboxLayer):
 
     defaultBases = (DATE_TIME_FIXTURE, PLONE_APP_CONTENTTYPES_FIXTURE)
@@ -246,72 +231,28 @@ PLONE_RESTAPI_DX_PAM_FUNCTIONAL_TESTING = FunctionalTesting(
 )
 
 
-if HAS_AT:
+class PloneRestApiDXIterateLayer(PloneSandboxLayer):
 
-    class PloneRestApiATLayer(PloneSandboxLayer):
+    defaultBases = (PLONEAPPITERATEDEX_FIXTURE,)
 
-        defaultBases = (DATE_TIME_FIXTURE, PLONE_FIXTURE)
+    def setUpZope(self, app, configurationContext):
+        import plone.restapi
 
-        def setUpZope(self, app, configurationContext):
-            import Products.ATContentTypes
+        xmlconfig.file("configure.zcml", plone.restapi, context=configurationContext)
+        xmlconfig.file("testing.zcml", plone.restapi, context=configurationContext)
 
-            self.loadZCML(package=Products.ATContentTypes)
-            import plone.app.dexterity
+        z2.installProduct(app, "plone.restapi")
 
-            self.loadZCML(package=plone.app.dexterity)
 
-            import plone.restapi
-
-            xmlconfig.file(
-                "configure.zcml", plone.restapi, context=configurationContext
-            )
-
-            z2.installProduct(app, "Products.Archetypes")
-            z2.installProduct(app, "Products.ATContentTypes")
-            z2.installProduct(app, "plone.app.collection")
-            z2.installProduct(app, "plone.app.blob")
-            z2.installProduct(app, "plone.restapi")
-
-        def setUpPloneSite(self, portal):
-            portal.acl_users.userFolderAddUser(
-                SITE_OWNER_NAME, SITE_OWNER_PASSWORD, ["Manager"], []
-            )
-            set_supported_languages(portal)
-
-            if portal.portal_setup.profileExists("Products.ATContentTypes:default"):
-                applyProfile(portal, "Products.ATContentTypes:default")
-            if portal.portal_setup.profileExists("plone.app.collection:default"):
-                applyProfile(portal, "plone.app.collection:default")
-
-            applyProfile(portal, "plone.app.dexterity:default")
-            applyProfile(portal, "plone.restapi:default")
-            applyProfile(portal, "plone.restapi:testing")
-            set_available_languages()
-            enable_request_language_negotiation(portal)
-            portal.portal_workflow.setDefaultChain(
-                "simple_publication_workflow"
-            )  # noqa: E501
-            states = portal.portal_workflow[
-                "simple_publication_workflow"
-            ].states  # noqa: E501
-            if six.PY2:  # issue 676
-                states["published"].title = u"Published with accent é".encode(
-                    "utf8"
-                )  # noqa: E501
-            else:
-                states["published"].title = u"Published with accent é"  # noqa: E501
-
-    PLONE_RESTAPI_AT_FIXTURE = PloneRestApiATLayer()
-    PLONE_RESTAPI_AT_INTEGRATION_TESTING = IntegrationTesting(
-        bases=(PLONE_RESTAPI_AT_FIXTURE,), name="PloneRestApiATLayer:Integration"
-    )
-    PLONE_RESTAPI_AT_FUNCTIONAL_TESTING = FunctionalTesting(
-        bases=(PLONE_RESTAPI_AT_FIXTURE, z2.ZSERVER_FIXTURE),
-        name="PloneRestApiATLayer:Functional",
-    )
-else:
-    PLONE_RESTAPI_AT_INTEGRATION_TESTING = PLONE_FIXTURE
-    PLONE_RESTAPI_AT_FUNCTIONAL_TESTING = PLONE_FIXTURE
+PLONE_RESTAPI_ITERATE_FIXTURE = PloneRestApiDXIterateLayer()
+PLONE_RESTAPI_ITERATE_INTEGRATION_TESTING = IntegrationTesting(
+    bases=(PLONE_RESTAPI_ITERATE_FIXTURE,),
+    name="PloneRestApiDXIterateLayer:Integration",
+)
+PLONE_RESTAPI_ITERATE_FUNCTIONAL_TESTING = FunctionalTesting(
+    bases=(PLONE_RESTAPI_ITERATE_FIXTURE, z2.ZSERVER_FIXTURE),
+    name="PloneRestApiDXIterateLayer:Functional",
+)
 
 
 class PloneRestApIBlocksLayer(PloneSandboxLayer):
