@@ -4,6 +4,7 @@ from datetime import datetime
 from datetime import time
 from datetime import timedelta
 from DateTime import DateTime
+from decimal import Decimal
 from plone import api
 from plone.app.discussion.interfaces import IDiscussionSettings
 from plone.app.testing import logout
@@ -31,8 +32,7 @@ import unittest
 
 
 class AdapterCM(object):
-    """Context manager that will temporarily register an adapter
-    """
+    """Context manager that will temporarily register an adapter"""
 
     def __init__(self, adapter, from_, provides):
         self.adapter = adapter
@@ -68,7 +68,7 @@ class TestDXContentSerializer(unittest.TestCase):
             test_choice_field=u"foo",
             test_date_field=date(2015, 7, 15),
             test_datetime_field=datetime(2015, 6, 20, 13, 22, 4),
-            test_decimal_field="1.1",
+            test_decimal_field=Decimal(1.1),
             test_dict_field={"foo": "bar", "spam": "eggs", "1": 1},
             test_float_field=1.5,
             test_frozenset_field=frozenset([1, 2, 3]),
@@ -410,13 +410,13 @@ class TestDXContentSerializer(unittest.TestCase):
     def test_richtext_serializer_context(self):
         """This checks if the context is passed in correctly.
 
-           We define a ITransformer, which returns the contexts portal_type.
-           This is then verfied.
+        We define a ITransformer, which returns the contexts portal_type.
+        This is then verfied.
         """
 
         class RichtextTransform(object):
             """RichttextValue to show that the context is correctly passed
-               in throughout the stack.
+            in throughout the stack.
             """
 
             def __init__(self, context):
@@ -433,7 +433,7 @@ class TestDXContentSerializer(unittest.TestCase):
         )
 
     def test_allow_discussion_by_default(self):
-        """ Not globally addable, not fti enabled, not obj instance enabled """
+        """Not globally addable, not fti enabled, not obj instance enabled"""
         self.portal.invokeFactory("Document", id=u"doc2")
         serializer = getMultiAdapter((self.portal.doc2, self.request), ISerializeToJson)
         obj = serializer()
@@ -591,7 +591,9 @@ class TestDXContentPrimaryFieldTargetUrl(unittest.TestCase):
         )
 
         self.portal.invokeFactory(
-            "DXTestDocument", id=u"doc2", test_primary_namedfile_field=None,
+            "DXTestDocument",
+            id=u"doc2",
+            test_primary_namedfile_field=None,
         )
 
         self.portal.doc1.creation_date = DateTime("2015-04-27T10:14:48+00:00")
