@@ -8,8 +8,6 @@ from plone.app.testing import SITE_OWNER_PASSWORD
 from plone.app.textfield.value import RichTextValue
 from plone.dexterity.utils import createContentInContainer
 from plone.registry.interfaces import IRegistry
-from plone.restapi import HAS_AT
-from plone.restapi.testing import PLONE_RESTAPI_AT_FUNCTIONAL_TESTING
 from plone.restapi.testing import PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
 from plone.restapi.testing import RelativeSession
 from plone.restapi.tests.helpers import result_paths
@@ -732,83 +730,62 @@ class TestSearchFunctional(unittest.TestCase):
         noLongerProvides(self.folder, INavigationRoot)
         transaction.commit()
 
+    @unittest.skipIf(not PLONE5, "No ISearchSchema in Plone 4")
+    def test_search_use_site_search_settings_with_navigation_root_and_vhm(self):
 
-class TestSearchATFunctional(unittest.TestCase):
-    layer = PLONE_RESTAPI_AT_FUNCTIONAL_TESTING
-
-    def setUp(self):
-        if not HAS_AT:
-            raise unittest.SkipTest("Skip tests if Archetypes is not present")
-        self.app = self.layer["app"]
-        self.portal = self.layer["portal"]
-        self.portal_url = self.portal.absolute_url()
-        self.request = self.portal.REQUEST
-        self.catalog = getToolByName(self.portal, "portal_catalog")
-
-        self.api_session = RelativeSession(self.portal_url)
-        self.api_session.headers.update({"Accept": "application/json"})
-        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)
-
-        # /plone/folder
-        with api.env.adopt_roles(["Manager"]):
-            self.folder = api.content.create(
-                type=u"ATTestFolder",
-                id=u"folder",
-                title=u"Some Folder",
-                container=self.portal,
-            )
-
-            # /plone/folder/doc
-            self.doc = api.content.create(
-                container=self.folder,
-                type=u"ATTestDocument",
-                id="doc",
-                title=u"Lorem Ipsum",
-                start=DateTime(1950, 1, 1, 0, 0),
-                effective=DateTime(1995, 1, 1, 0, 0),
-                expires=DateTime(1999, 1, 1, 0, 0),
-                testIntegerField=42,
-                testLinesField=["Keyword1", "Keyword2", "Keyword3"],
-                testBooleanField=True,
-                testTextField=u"<p>Some Text</p>",
-            )
-
-            # /plone/folder/other-document
-            self.doc2 = api.content.create(
-                container=self.folder,
-                type=u"ATTestDocument",
-                id="other-document",
-                title=u"Other Document",
-                description=u"\xdcbersicht",
-                start=DateTime(1975, 1, 1, 0, 0),
-                effective=DateTime(2015, 1, 1, 0, 0),
-                expires=DateTime(2020, 1, 1, 0, 0),
-                testLinesField=["Keyword2", "Keyword3"],
-                testBooleanField=False,
-            )
-
-            # /plone/doc-outside-folder
-            api.content.create(
-                container=self.portal,
-                type=u"ATTestDocument",
-                id="doc-outside-folder",
-                title=u"Doc outside folder",
+        if "virtual_hosting" not in self.app.objectIds():
+            # If ZopeLite was imported, we have no default virtual
+            # host monster
+            from Products.SiteAccess.VirtualHostMonster import (
+                manage_addVirtualHostMonster,
             )
 
+            manage_addVirtualHostMonster(self.app, "virtual_hosting")
+        alsoProvides(self.folder, INavigationRoot)
         transaction.commit()
 
-    def test_full_objects_retrieval(self):
-        query = {
-            "SearchableText": "lorem",
-            "metadata_fields": ["portal_type", "review_state"],
-            "fullobjects": True,
-        }
-        response = self.api_session.get("/@search", params=query)
+        vhm_url = "%s/VirtualHostBase/http/plone.org/plone/VirtualHostRoot/%s" % (
+            self.app.absolute_url(),
+            "/folder/@search",
+        )
+        response = self.api_session.get(
+            vhm_url, params={"use_site_search_settings": 1, "path": "/folder"}
+        ).json()
+        titles = [u"Some Folder", u"Lorem Ipsum", u"Other Document"]
+        self.assertEqual([item["title"] for item in response["items"]], titles)
 
-        self.assertEqual(
-            {u"data": u" Some Text ", u"content-type": u"text/plain"},
-            response.json()["items"][0]["testTextField"],
-        )
-        self.assertEqual(
-            self.portal_url + u"/folder/doc", response.json()["items"][0]["@id"]
+        noLongerProvides(self.folder, INavigationRoot)
+        transaction.commit()
+
+    @unittest.skipIf(not PLONE5, "No ISearchSchema in Plone 4")
+    def test_search_use_site_search_settings_with_vhm(self):
+
+        if "virtual_hosting" not in self.app.objectIds():
+            # If ZopeLite was imported, we have no default virtual
+            # host monster
+            from Products.SiteAccess.VirtualHostMonster import (
+                manage_addVirtualHostMonster,
+            )
+
+            manage_addVirtualHostMonster(self.app, "virtual_hosting")
+        transaction.commit()
+
+        vhm_url = "%s/VirtualHostBase/http/plone.org/plone/VirtualHostRoot/%s" % (
+            self.app.absolute_url(),
+            "/@search",
         )
+        response = self.api_session.get(
+            vhm_url, params={"use_site_search_settings": 1, "path": "/"}
+        ).json()
+        titles = [
+            "Some Folder",
+            "Lorem Ipsum",
+            "Other Document",
+            "Another Folder",
+            "Document in second folder",
+            "Doc outside folder",
+        ]
+        self.assertEqual([item["title"] for item in response["items"]], titles)
+
+        noLongerProvides(self.folder, INavigationRoot)
+        transaction.commit()
